methodChannel property
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('device_calendar_plus_android');
The method channel used to interact with the native platform.
@visibleForTesting
final methodChannel = const MethodChannel('device_calendar_plus_android');